pub struct BFSR(/* private fields */);Expand description
The BusFault Status Register shows the status of bus errors resulting from instruction fetches and data accesses and indicates memory access faults detected during a bus operation.
Implementations
Sourceimpl BFSR
impl BFSR
pub const DOC_IBUSERR: &'static str = r#"Instruction bus error. Records whether a BusFault on an instruction prefetch has occurred."#
pub const DOC_PRECISERR: &'static str = r#"Precise data bus error."#
pub const DOC_IMPRECISERR: &'static str = r#"Imprecise data bus error."#
pub const DOC_UNSTKERR: &'static str = r#"BusFault on unstacking for a return from exception."#
pub const DOC_STKERR: &'static str = r#"BusFault on stacking for exception entry."#
pub const DOC_LSPERR: &'static str = r#"BusFault during floating point lazy state preservation (only when FPU present)."#
pub const DOC_BFARVALID: &'static str = r#"BusFault Address Register valid flag. BFAR holds a valid fault address."#
Sourcepub fn IBUSERR(&self) -> bool
pub fn IBUSERR(&self) -> bool
Instruction bus error. Records whether a BusFault on an instruction prefetch has occurred.
Sourcepub fn IMPRECISERR(&self) -> bool
pub fn IMPRECISERR(&self) -> bool
Imprecise data bus error.