pub struct MMFSR(/* private fields */);Expand description
The MemManage fault status register indicates a memory access violation detected by the Memory Protection Unit (MPU).
Implementations
Sourceimpl MMFSR
impl MMFSR
pub const DOC_IACCVIOL: &'static str = r#"Instruction access violation. The processor attempted an instruction fetch from a location that does not permit execution. Faulting instruction: see `PC`. "#
pub const DOC_DACCVIOL: &'static str = r#"Data access violation. The processor attempted a load or store at a location that does not permit the operation. Faulting instruction: see `PC`. Address of the attempted access: see `MMFAR`. "#
pub const DOC_MUNSTKERR: &'static str = r#"MemManage fault on unstacking for a return from exception. Fault address - see MMFAR. Potential reasons: - Stack pointer is corrupted - MPU region for the stack changed during execution of the exception handler "#
pub const DOC_MSTKERR: &'static str = r#" MemManage fault on stacking for exception entry. The SP is still adjusted but the values in the context area on the stack might be incorrect. The processor has not written a fault address to the MMFAR. Potential reasons: - Stack pointer is corrupted or not initialized - Stack is reaching a region not defined by the MPU as read/write memory. "#
pub const DOC_MLSPERR: &'static str = r#"MemManage fault during floating point lazy state preservation (only Cortex-M4 with FPU)."#
pub const DOC_MMARVALID: &'static str = r#"MemManage Fault Address Register (MMFAR) valid flag. SCB->MMFAR holds a valid fault address."#
Sourcepub fn IACCVIOL(&self) -> bool
pub fn IACCVIOL(&self) -> bool
Instruction access violation.
The processor attempted an instruction fetch from a location that does not permit execution.
Faulting instruction: see PC.
Sourcepub fn DACCVIOL(&self) -> bool
pub fn DACCVIOL(&self) -> bool
Data access violation.
The processor attempted a load or store at a location that does not permit the operation.
Faulting instruction: see PC.
Address of the attempted access: see MMFAR.
Sourcepub fn MUNSTKERR(&self) -> bool
pub fn MUNSTKERR(&self) -> bool
MemManage fault on unstacking for a return from exception. Fault address - see MMFAR. Potential reasons: - Stack pointer is corrupted - MPU region for the stack changed during execution of the exception handler
Sourcepub fn MSTKERR(&self) -> bool
pub fn MSTKERR(&self) -> bool
MemManage fault on stacking for exception entry.
The SP is still adjusted but the values in the context area on the stack might be incorrect. The processor has not written a fault address to the MMFAR. Potential reasons:
- Stack pointer is corrupted or not initialized
- Stack is reaching a region not defined by the MPU as read/write memory.